#
# spec file for package python-pep8-naming
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pep8-naming
Version:        0.14.1
Release:        1.2
Summary:        Flake8 plugin for checking PEP-8 naming conventions
License:        MIT
URL:            https://github.com/PyCQA/pep8-naming
Source:         https://files.pythonhosted.org/packages/source/p/pep8-naming/pep8-naming-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-flake8 >= 5.0.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module flake8 >= 5.0.0}
# /SECTION
%python_subpackages

%description
Check the PEP-8 naming conventions.

This module provides a plugin for ``flake8``, the Python code checker.

(It replaces the plugin ``flint-naming`` for the ``flint`` checker.)

%prep
%autosetup -p1 -n pep8-naming-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python -B run_tests.py
}

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license LICENSE
%{python_sitelib}/pep8ext_naming.py*
%pycache_only %{python_sitelib}/__pycache__/pep8ext_naming.*.py*
%{python_sitelib}/pep8_naming-%{version}.dist-info

%changelog
* Tue Jun  4 2024 Dirk Müller <dmueller@suse.com>
- update to 0.14.1:
  * Require Python 3.8 or later.
  * Drop support for Python 3.7.
  * Add support for Python 3.12.
  * Ignore methods decorated by @typing.override.
  * Perform case-sensitive ignore-names globbing on all
    platforms.
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 0.13.3:
  * Formally require flake8 5.0.0 or later.
  * Add support for Python 3.11.
* Mon Sep 19 2022 Dirk Müller <dmueller@suse.com>
- update to 0.13.2:
  * Formally require Python 3.7 or later using ``python_requires``.
  * Fix warnings related to deprecated options syntax.
  * ``setUpModule`` and ``tearDownModule`` are now exempted by default.
- drop add-missing-option-for-testsuite.patch (obsolete)
* Mon Feb  7 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.12.1:
  * Fix potential stack exhaustion in the N818 check.
  * flake8 3.9.1 or later is now required.
  * N818 checks exception class names for an "Error" suffix
  * asyncSetUp and asyncTearDown are now exempted by default.
- Remove pep8-naming-pr157-exception-names.patch, merged.
- Add patch add-missing-option-for-testsuite.patch:
  * Merged commit from upstream to make tests pass.
* Fri Jun 18 2021 Ben Greiner <code@bnavigator.de>
- Add pep8-naming-pr157-exception-names.patch for compatibility
  with flake8 >= 3.9.1; gh#PyCQA/pep8-naming#157
- Update URL, clean up specfile (-B and PYTHONDONTWRITEBYTECODE=1
  are redundant)
* Sat Jul 11 2020 Arun Persaud <arun@gmx.de>
- update to version 0.11.1:
  * Fix an AST-related AttributeError when processing decorator lists.
- changes from version 0.11.0:
  * __class_getitem__ is now recognized as a class method.
  * Support ast.Call nodes in decorator lists (@decorator(arg)).
  * As a performance improvement, onl
* Tue Mar 24 2020 pgajdos@suse.com
- version update to 0.10.0
  * ``--ignore-names`` now supports globbing and applies to the N804 and N805
    checks.
  * "acronym" imports are now treated as their own error code (N817).
  * Metaclass detection has been improved.
  * Annotated variable declarations (PEP 526) and ``:=`` variable assignments
    are now supported.
* Sat Dec  7 2019 Arun Persaud <arun@gmx.de>
- update to version 0.9.1:
  * Fix line number offsets when reporting errors involving functions
    with decorators in Python 3.8 and later.
- changes from version 0.9.0:
  * Drop support for Python 3.3 and 3.4.
  * Support positional-only arguments in Python 3.8.
  * Recognize abc.ABCMeta as a metaclass base type.
  * ignore-names now also applies to the N803 check.
  * Handle assigning exceptions to object attributes in Python 2.
* Thu Feb 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.8.2:
  * Fix a problem with ignore-names option initialization.
  * ignore-names now also applies to the N806, N815, and N816 checks.
  * failureException, longMessage, and maxDiff have been added to the default ignore-names list.
  * Allow lowercase names to be imported as just _.
  * Allow function arguments to be named just _.
  * Support Python 2's tuple syntax in except clauses.
* Sat Feb  2 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 0.8.0:
  * Detect N806 errors within for loops and exception handlers.
  * Improve support for non-ASCII characters.
  * Detect mixedCased variable names at class (N815) and global (N816)
    scope.
  * Ignore Django's setUpTestData method by default.
  * Fix column offsets for N803, N804, and N805 under Python 3.
  * Detect underscores within class names as N801 errors.
  * Don't flag __getattr__ and __dir__ as N807 errors. (See PEP 562).
  * async function and method names are now checked.
  * Detect N806 errors in generator expressions and comprehensions.
  * Detect N81x errors in import x as y statements.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Use noun phrase in summary.
* Thu May 24 2018 toddrme2178@gmail.com
- Update to 0.7.0
  * Detect N806 in ``with ... as ...:`` statements.
  * Detect N806 in multiple assignment statements, e.g., ``Foo, Bar =
    unpacking``.
  * Allow class names to be properly ignored.
  * Remove spurious 'xxx' from error message
  * Detect N807 within conditional statements.
- Update to 0.6.1
  * Fix N804 check for ``cls`` used in metaclass methods (See also
    https://github.com/PyCQA/pep8-naming/issues/53)
- Update to 0.6.0
  * Separate check for ``__`` in function names to its own code: N807
  * Consider all metaclass methods to be class methods
- Spec file cleanups
* Wed Jan  3 2018 arun@gmx.de
- specfile:
  * update copyright year
  * requre flake8-polyfill
- update to version 0.5.0:
  * Add configurable list of classmethod and staticmethod decorators
  * Print the offending name as part of the error message
  * Correct N804/N805 for __init_subclass__
* Mon Aug 14 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Update to version 0.4.1
  * Fix option parsing for Flake8 3.0 (store parsed value on class)
- Update to version 0.4.0
  * Fix integration with Flake8 3.0.0b1
  * Start testing against Python 3.5
- Update to version 0.3.3
  * Fix bug where ignored names were not properly split into a
    list.
- Update to version 0.3.2
  * Fix bug trying to call split on a list.
- Update to version 0.3.1
  * Fix optparse exception resulting from trying to register an
    option twice.
- Update to version 0.3.0
  * Relaxed N806 checking for use with namedtuples
  * Add --ignore-names which allows the user to specify a list of
    names to ignore. By default this includes setUp, tearDown,
    setUpClass, and tearDownClass.
* Thu Jul 10 2014 toddrme2178@gmail.com
- Update to 0.2.2
  - Do not require setuptools in setup.py. It works around an
    issue with pip and Python 3.
  - __new__ is now considered as classmethod implicitly
  - Run unit tests on travis-ci.org for python2.6, 2.7, 3.2, and 3.3
  - Add unit tests and support running them with setup.py
  - Support Python 3.4
* Mon Mar 24 2014 toddrme2178@gmail.com
- Initial version
